/**
 * @description router全局配置，如有必要可分文件抽离，其中asyncRoutes只有在intelligence模式下才会用到，pro版只支持remixIcon图标，具体配置请查看vip群文档
 */
import Vue from 'vue'
import VueRouter from 'vue-router'
import Layout from '@/vab/layouts'
/* 多级路由不需要缓存时可放开注释直接引入 用法component:VabEmptyLayout*/
/* import VabEmptyLayout from '@/vab/layouts/VabEmptyLayout' */
import { publicPath, routerMode } from '@/config'

Vue.use(VueRouter)
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login'),
    meta: {
      hidden: true,
    },
  },
  {
    path: '/register',
    component: () => import('@/views/register'),
    meta: {
      hidden: true,
    },
  },
  {
    path: '/callback',
    component: () => import('@/views/callback'),
    meta: {
      hidden: true,
    },
  },
  {
    path: '/403',
    name: '403',
    component: () => import('@/views/403'),
    meta: {
      hidden: true,
    },
  },
  // {
  //   path: '/404',
  //   name: '404',
  //   component: () => import('@/views/404'),
  //   meta: {
  //     hidden: false,
  //   },
  // },
]

export const asyncRoutes = [
  {
    path: '/',
    name: 'Root',
    component: Layout,
    redirect: '/index',
    meta: {
      title: '首页',
      icon: 'home-2-line',
    },
    children: [
      {
        path: 'index',
        name: 'Index',
        component: () => import('@/views/index'),
        meta: {
          title: '首页',
          icon: 'home-2-line',
          noClosable: true,
        },
      },
    ],
  },

  // 会员管理
  {
    path: '/member',
    name: 'Member',
    component: Layout,
    redirect: '/member/index',
    meta: {
      title: '会员',
      icon: 'reactjs-line',
    },
    children: [
      {
        path: 'index',
        name: 'Index',
        component: () => import('@/views/member/index'),
        meta: {
          title: '会员列表',
          icon: 'account-pin-circle-fill',
          // noClosable: true,
        },
      },
      {
        path: 'record',
        name: 'Record',
        component: () => import('@/views/member/record'),
        meta: {
          title: '积分记录',
          icon: 'file-list-2-line',
        },
      },
      {
        path: 'category',
        name: 'Category',
        component: () => import('@/views/member/category'),
        meta: {
          title: '配置管理',
          icon: 'account-pin-circle-fill',
          // noClosable: true,
        },
      },
    ],
  },

  //组织
  {
    path: '/organization',
    name: 'Organization',
    component: Layout,
    redirect: '/organization/student',
    meta: {
      title: '组织',
      icon: 'organization-chart',
    },
    children: [
      {
        path: 'administration',
        name: 'admin',
        component: () => import('@/views/organization/administration'),
        meta: {
          title: '管理员管理',
          icon: 'admin-line',
        },
      },
      // {
      //   path: 'department',
      //   name: 'Department',
      //   component: () => import('@/views/organization/department'),
      //   meta: {
      //     title: '部门管理',
      //     icon: 'building-2-line',
      //     noClosable: true,
      //   },
      // },
      {
        path: 'role',
        name: 'Role',
        component: () => import('@/views/organization/role'),
        meta: {
          title: '角色管理',
          icon: 'file-list-3-line',
        },
      },
    ],
  },
  //系统
  {
    path: '/setting',
    name: 'Setting',
    component: Layout,
    redirect: '/setting/personal',
    meta: {
      title: '系统',
      icon: 'reactjs-line',
    },
    children: [
      // {
      //   path: 'menu',
      //   name: 'Menu',
      //   component: () => import('@/views/organization/menu'),
      //   meta: {
      //     title: '菜单管理',
      //     icon: 'file-list-2-line',
      //   },
      // },
      {
        path: 'personal',
        name: 'Personal',
        component: () => import('@/views/setting/personal'),
        meta: {
          title: '个人中心',
          icon: 'file-list-2-line',
        },
      },
    ],
  },

  {
    path: '*',
    redirect: '/404',
    meta: {
      hidden: true,
    },
  },
]

const router = createRouter()

export function resetRouter(routes = constantRoutes) {
  router.matcher = createRouter(routes).matcher
}

function createRouter(routes = constantRoutes) {
  console.log(constantRoutes, 'constantRoutes')
  return new VueRouter({
    base: publicPath,
    mode: routerMode,
    scrollBehavior: () => ({
      y: 0,
    }),
    routes: routes,
  })
}

const originalPush = VueRouter.prototype.push
VueRouter.prototype.push = function push(location, onResolve, onReject) {
  if (onResolve || onReject)
    return originalPush.call(this, location, onResolve, onReject)
  return originalPush.call(this, location).catch((err) => err)
}

export default router
